#[non_exhaustive]pub enum ImageFallback {
AltText,
Url,
AltTextAndUrl,
}Expand description
Text used to represent Markdown images in rendered terminal output.
This option does not load or render image resources. It controls whether the text fallback
contains the image description, destination, or both. AltText is the
default.
Example
use tui_markdown::{from_str_with_options, ImageFallback, Options};
let options = Options::default().image_fallback(ImageFallback::AltTextAndUrl);
let text = from_str_with_options("", &options);
assert_eq!(
text.to_string(),
"[img] Architecture diagram (diagram.png)"
);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AltText
Show [img] followed by the description, or the destination when the description is empty.
Url
Show [img] followed by the destination, ignoring the description.
AltTextAndUrl
Show [img] {description} ({destination}), omitting either value when it is empty.