DefaultStyleSheet

Struct DefaultStyleSheet 

pub struct DefaultStyleSheet;
The default style set

This style sheet will be used by default if the user does not provide their own implementation.

Styles are:

  • H1: white on cyan, bold, underlined
  • H2: cyan, bold
  • H3: cyan, bold, italic
  • H4-H6: light cyan, italic
  • code: white on black
  • link: blue, underlined
  • blockquote: green
  • metadata block: light yellow
  • heading markers: one to six # characters
  • code block fences: three backticks
  • raw HTML: dim
  • inline math: magenta, italic
  • display math: magenta
  • footnote references: dim, italic
  • footnote definitions: dim
  • definition list terms: bold
  • definition list descriptions: the surrounding style
  • note alerts: blue
  • tip alerts: green
  • important alerts: magenta
  • warning alerts: yellow
  • caution alerts: red
  • table headers: bold cyan
  • table cells: the surrounding style
  • table borders: dark gray
  • image fallback text: dim and italic